@@ -3,6 +3,7 @@ import git
 import argparse
 from rich.console import Console
 from rich.panel import Panel
+from bossman import Bossman
 
 console = Console()
 
@@ -12,22 +13,21 @@ def init(subparsers: argparse._SubParsersAction):
   parser.add_argument("glob", nargs="?", default="*", help="select resources by glob pattern")
   parser.set_defaults(func=exec)
 
-def exec(bossman, glob, force=False, **kwargs):
+def exec(bossman: Bossman, glob, force=False, **kwargs):
   resources = bossman.get_resources(glob=glob)
   for resource in resources:
     console.rule(str(resource))
     status = bossman.get_resource_status(resource)
-    missing = list(status.missing_changesets)
-    console.print(":notebook: {} changes pending".format(len(missing)), justify="center")
+    missing_revisions = list(status.missing_revisions)
+    console.print(":notebook: {} changes pending".format(len(missing_revisions)), justify="center")
     if status.dirty:
       if not force:
         console.print(":stop_sign: [magenta]dirty, skipping[/magenta] :stop_sign:", justify="center")
         continue
       else:
         console.print(":exclamation_mark: [red]dirty, force applying[/red] :exclamation_mark:", justify="center")
-    for (idx, changeset) in enumerate(missing):
-      console.print(Panel(changeset, title="{}/{}".format(idx+1, len(missing))))
-      for change in changeset.resource_changes.values():
-        bossman.apply_change(changeset, change)
+    for (idx, revision) in enumerate(missing_revisions):
+      console.print(Panel(revision, title="{}/{}".format(idx+1, len(missing_revisions))))
+      bossman.apply_change(resource, revision)
     else:
       console.print(":cookie: [green]all done[green] :cookie:", justify="center")
