@@ -1,16 +1,17 @@
 
-class BossmanRuntimeError(RuntimeError):
+class BossmanError(RuntimeError):
   """
   Base class for bossman-specific runtime errors.
   """
-  pass
+  def __rich__(self):
+    return "{}: {}".format(self.__class__.__name__, " ".join(self.args))
 
-class BossmanConfigurationError(BossmanRuntimeError):
+class BossmanConfigurationError(BossmanError):
   """
   Configuration errors indicate that improper options have been passed to bossman.
   """
 
-class MultipleMatchingPluginsError(BossmanRuntimeError):
+class MultipleMatchingPluginsError(BossmanError):
   """
   Bossman matches plugins to resources using glob patterns.
   """
